@@ -560,7 +560,8 @@ class PHOENIXLibrary:
                 assert np.all(self.metadata[k] == metadata[k])
             for k in ["metallicity", "filename", "chromatic-version"]:
                 self.metadata[k] = np.hstack([self.metadata[k], metadata[k]])
-            self.models = self.models | models
+            self.models.update(**models)
+
         except (AttributeError, AssertionError):
             self.metadata = metadata
             self.models = models
@@ -673,7 +674,9 @@ class PHOENIXLibrary:
 
         return (np.min(w), np.max(w), len(w))
 
-    def _get_spectrum_from_grid(self, key, wavelength=None, wavelength_edges=None):
+    def _get_average_spectrum_from_grid(
+        self, key, wavelength=None, wavelength_edges=None
+    ):
         if (wavelength is None) and (wavelength_edges is None):
             return self.models[key]
         else:
@@ -704,7 +707,7 @@ class PHOENIXLibrary:
                 )["y"]
                 return self.wavelength_cached_models[wavelength_key][key]
 
-    def get_spectrum(
+    def get_average_spectrum(
         self,
         temperature=5780,
         logg=4.43,
@@ -815,7 +818,7 @@ class PHOENIXLibrary:
         if N == 1:
             weights = [1]
             key = (bounding_temperature[0], bounding_logg[0], bounding_metallicity[0])
-            spectrum = self._get_spectrum_from_grid(
+            spectrum = self._get_average_spectrum_from_grid(
                 key, wavelength=wavelength, wavelength_edges=wavelength_edges
             ).flatten()
         else:
@@ -835,7 +838,7 @@ class PHOENIXLibrary:
                         key = (t, g, z)
                         try:
                             this_log_spectrum = np.log(
-                                self._get_spectrum_from_grid(
+                                self._get_average_spectrum_from_grid(
                                     key,
                                     wavelength=wavelength,
                                     wavelength_edges=wavelength_edges,
@@ -928,13 +931,13 @@ class PHOENIXLibrary:
 
                 # how long does it take to retrieve a spectrum that exists?
                 start = get_current_seconds()
-                self.get_spectrum(temperature=3000, logg=4.5, metallicity=0.0)
+                self.get_average_spectrum(temperature=3000, logg=4.5, metallicity=0.0)
                 dt = get_current_seconds() - start
                 timings["get spectrum at grid point"].append(dt)
 
                 # how long does it take to retrieve a spectrum that needs to be interpolated?
                 start = get_current_seconds()
-                self.get_spectrum(temperature=3456, logg=5.67, metallicity=0.0)
+                self.get_average_spectrum(temperature=3456, logg=5.67, metallicity=0.0)
                 dt = get_current_seconds() - start
                 timings["get interpolated spectrum"].append(dt)
 
@@ -950,4 +953,4 @@ class PHOENIXLibrary:
 
 
 phoenix_library = PHOENIXLibrary(photons=True)
-get_phoenix_photons = phoenix_library.get_spectrum
+get_phoenix_photons = phoenix_library.get_average_spectrum
